NAME

WWW::MailboxOrg::API::Account - Account management API

VERSION

version 0.001

NAME

WWW::MailboxOrg::API::Account - Account management API

add

$api->account->add(
    account      => 'user@example.com',
    password     => 'secret123',
    plan         => 'basic',
    tarifflimits => { ... },
    memo         => 'Optional note',
);

Add a new account. Required: account, password, plan.

del

$api->account->del(account => 'user@example.com');

Delete an account.

get

$api->account->get(account => 'user@example.com');

Get account details.

list

$api->account->list;
$api->account->list(account => 'admin@example.com');

List accounts. Optional account filter.

set

$api->account->set(
    account => 'user@example.com',
    plan    => 'profi',
    memo    => 'Updated note',
);

Update account settings. At least account required.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/getty/p5-www-mailboxorg/issues.

IRC

Join #perl-help on irc.perl.org or message Getty directly.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <getty@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.